import React from 'react'

import TodoCard from './todoCard.js'

import styles from './todoBoard.module.css'

export default function TodoBoard(props) {
  const {
    columns,
    cards,
    userId,
    categories,
    onCardClick,
    selectedGroup,
  } = props

  const clickableTypes = Object.keys(columns).reduce((acc, key) => {
    const col = columns[key]
    if (col.clickable) {
      acc.push(key)
    }
    return acc
  }, [])

  return (
    <div className={styles.tableContainer}>
      <div className={styles.table}>
        {Object.keys(columns).map((key) => {
          const category = columns[key]
          const cardsToShow = cards.filter((card) => {
            const shouldHide =
              card.state !== key ||
              (selectedGroup !== null &&
                selectedGroup !== 'uncat' &&
                card.group !== selectedGroup) ||
              (selectedGroup === 'uncat' && card.group !== undefined)

            return !shouldHide
          })
          return (
            <div className={styles.tableCol} key={key}>
              <div className={styles.categoryName}>{category.name}</div>

              {cardsToShow.length === 0 && (
                <div className={styles.empty}>Üres</div>
              )}
              {cardsToShow.map((card, i) => {
                return (
                  <TodoCard
                    key={i}
                    cardData={card}
                    userId={userId}
                    categories={categories}
                    onClick={onCardClick}
                    clickable={clickableTypes.includes(key)}
                  />
                )
              })}
            </div>
          )
        })}
      </div>
    </div>
  )
}
